Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
Operation string `json:"operation"`
Params map[string]interface{} `json:"params,omitempty"`
Input map[string]interface{} `json:"input,omitempty"`
Output string `json:"output,required"`
}
The struct config of operation.
type Factory ¶
type Factory func(ctx InitContext) (Operation, error)
type InitContext ¶
type InitContext interface {
// Params
Params() map[string]interface{}
// MapperFactory gets the mapper factory associated with the operation host
MapperFactory() mapper.Factory
// Logger logger to using during initialization, operation implementations should not
// keep a reference to this
Logger() log.Logger
}
Click to show internal directories.
Click to hide internal directories.